QuadBez
=======

::

   from kurbopy import QuadBez, Point

   bez = QuadBez(
      Point(50.0, 100.0),
      Point(75.0, 100.0),
      Point(100.0, 100.0),
   )

.. autoclass:: kurbopy.QuadBez
   :members:
   :undoc-members:
